#ifndef RESISTORS_H
#define RESISTORS_H

#include <QDialog>

namespace Ui {
    class Resistors;
}

class Resistors : public QDialog
{
    Q_OBJECT

public:
    Resistors(QWidget *parent = 0);
    ~Resistors();

public slots:
    void recalculate();

protected:
    void changeEvent(QEvent *e);
    void resizeEvent(QResizeEvent *event);

private:
    Ui::Resistors *ui;
    bool portrait;
    bool fiveBand;

    QIcon createIcon(QString colorName);
};

#endif // RESISTORS_H
